Hi,

tested x86_64-linux, committed to mainline.

Paolo.

/////////////////
2011-11-18  Harti Brandt  <hartmut.bra...@dlr.de>

        PR libstdc++/51209
        * include/bits/hashtable.h (_Hashtable<>::_M_find_node): Return
        nullptr when no node is found.
        * include/tr1/hashtable.h (_Hashtable<>::_M_find_node): Return
        zero when no node is found.
Index: include/tr1/hashtable.h
===================================================================
--- include/tr1/hashtable.h     (revision 181477)
+++ include/tr1/hashtable.h     (working copy)
@@ -813,7 +813,7 @@
     }
 
   // Find the node whose key compares equal to k, beginning the search
-  // at p (usually the head of a bucket).  Return nil if no node is found.
+  // at p (usually the head of a bucket).  Return zero if no node is found.
   template<typename _Key, typename _Value,
           typename _Allocator, typename _ExtractKey, typename _Equal,
           typename _H1, typename _H2, typename _Hash, typename _RehashPolicy,
@@ -829,7 +829,7 @@
       for (; __p; __p = __p->_M_next)
        if (this->_M_compare(__k, __code, __p))
          return __p;
-      return false;
+      return 0;
     }
 
   // Insert v in bucket n (assumes no element with its key already present).

Reply via email to
Index: include/bits/hashtable.h
===================================================================
--- include/bits/hashtable.h    (revision 181477)
+++ include/bits/hashtable.h    (working copy)
@@ -873,7 +873,7 @@
     }
 
   // Find the node whose key compares equal to k, beginning the search
   // at p (usually the head of a bucket).  Return nil if no node is found.
   template<typename _Key, typename _Value,
           typename _Allocator, typename _ExtractKey, typename _Equal,
           typename _H1, typename _H2, typename _Hash, typename _RehashPolicy,
@@ -889,7 +889,7 @@
       for (; __p; __p = __p->_M_next)
        if (this->_M_compare(__k, __code, __p))
          return __p;
-      return false;
+      return nullptr;
     }
 
   // Insert v in bucket n (assumes no element with its key already present).
@@ -873,7 +873,7 @@
 
   // Find the node whose key compares equal to k, beginning the search
-  // at p (usually the head of a bucket).  Return nil if no node is found.
+  // at p (usually the head of a bucket).  Return nullptr if no node is found.
   template<typename _Key, typename _Value,
           typename _Allocator, typename _ExtractKey, typename _Equal,